@@ -4,6 +4,22 @@
 
  ETHERNET
 
+     .---.--------------.
+     | 7 | Application  |
+     |---|--------------|
+     | 6 | Presentation |
+     |---|--------------|
+     | 5 | Session      |
+     |---|--------------|
+     | 4 | Transport    |
+     |---|--------------|
+     | 3 | Network      |
+     #===#==============#
+     # 2 # Data Link    #
+     #===#==============#
+     | 1 | Physical     |
+     '---'--------------'
+
 
 """
 
